@@ -8,8 +8,6 @@ import django.urls.exceptions
 import redis
 import requests
 from decouple import config
-from redis.exceptions import ConnectionError
-from requests.exceptions import InvalidSchema
 from rest_framework.exceptions import ValidationError
 
 
@@ -20,6 +18,8 @@ class Client:
     CACHE_OCCURRENCE_TTL = 60 * 45
     CACHE_GROUP_KEY_TTL = 60 * 45
 
+    timeout = int(config("REQUESTS_TIMEOUT", default=30))
+
     __instance = None
 
     def __new__(cls, *args, **kwargs):
@@ -219,6 +219,7 @@ class Client:
                 params=self.__build_params(
                     views, occurrences, snake_keys, page_size, page
                 ),
+                timeout=Client.timeout,
             )
 
         if snake_keys and len(snake_keys) > keys_number:
@@ -318,10 +319,17 @@ class Client:
 
         # 5. Fetch the remaining items.
 
-        translations = requests.get(
-            self._filter_url(language),
-            params=self.__build_params(views, occurrences, snake_keys, page_size, page),
-        ).json()
+        translations = (
+            requests.get(
+                self._filter_url(language),
+                params=self.__build_params(
+                    views, occurrences, snake_keys, page_size, page
+                ),
+                timeout=Client.timeout,
+            )
+            .json()
+            .get("results")
+        )
 
         # 6. Cache new translations and assemble output.
         result = {**result, **_cache_translations(translations)}
@@ -333,5 +341,5 @@ class Client:
 
         :returns: url for the `filter` request
         """
-        _url = urlparse(f"{self.address}:{self.port}/api/v1/translations/{language}")
+        _url = urlparse(f"{self.address}:{self.port}/api/v1/translations/{language}/")
         return _url.geturl()
